<?php declare(strict_types=1);

namespace App\Controller;

use App\Entity\Chipset;
use App\Form\ChipsetType;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\{Request, Response};
use Symfony\Component\Routing\Annotation\Route;

#[Route('/chipset')]
class ChipsetController extends AbstractController {
	use FormControllerBase;

	protected const ENTITY = Chipset::class;
	protected const TEMPLATE_PATH = 'chipset/';
	protected const ROUTE_PREFIX = 'chipset_';
	protected const FORM = ChipsetType::class;

	public function __construct(private readonly EntityManagerInterface $entityManager)
	{
	}

	#[Route('/', name: 'chipset_index', methods: ['GET'])]
	public function index(): Response
	{
		return $this->itemListView('chipsets', []);
	}

	#[Route('/new', name: 'chipset_new', methods: ['GET', 'POST'])]
	public function new(Request $request): Response
	{
		return $this->itemCreate($request, 'chipset');
	}

	#[Route('/{id}', name: 'chipset_show', methods: ['GET'])]
	public function show(Chipset $chipset): Response
	{
		return $this->itemView($chipset, 'chipset');
	}

	#[Route('/{id}/edit', name: 'chipset_edit', methods: ['GET', 'POST'])]
	public function edit(Request $request, Chipset $chipset): Response
	{
		return $this->itemUpdate($request, $chipset, 'chipset');
	}

	#[Route('/{id}', name: 'chipset_delete', methods: ['POST'])]
	public function delete(Request $request, Chipset $chipset): Response
	{
		return $this->deleteCSRF($request, $chipset);
	}
}
